"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const state_1 = require("./state");
const nodepath = require("path");
const titleManager_1 = require("./managers/titleManager");
const markdownManager_1 = require("./managers/markdownManager");
const pathManager_1 = require("./managers/pathManager");
const seoTitleManager_1 = require("./managers/seoTitleManager");
const pathBarManager_1 = require("./managers/pathBarManager");
const fileListManager_1 = require("./managers/fileListManager");
const fsWalkManager_1 = require("./managers/fsWalkManager");
const pathInfoManager_1 = require("./managers/pathInfoManager");
const copyManager_1 = require("./managers/copyManager");
class Processor {
    constructor(config, contentGenerator) {
        this.config = config;
        this.contentGenerator = contentGenerator;
        const state = new state_1.State();
        this.state = state;
        this.pathManager = new pathManager_1.default(config);
        this.titleManager = new titleManager_1.default(config, state, this.pathManager);
        this.markdownManager = new markdownManager_1.default(this.pathManager);
        this.seoTitleManager = new seoTitleManager_1.default(config, state, this.titleManager, this.pathManager);
        this.fsWalkManager = new fsWalkManager_1.default(this.pathManager);
        this.pathInfoManager = new pathInfoManager_1.default(config, state, this.pathManager, this.titleManager);
        this.pathBarManager = new pathBarManager_1.default(config, state, this.pathManager, this.titleManager, this.pathInfoManager, contentGenerator);
        this.fileListManager = new fileListManager_1.default(config, state, this.pathManager, this.titleManager, this.pathInfoManager, this.fsWalkManager, contentGenerator);
        this.copyManager = new copyManager_1.default(this.pathManager);
    }
    startFromFile(relFile) {
        return __awaiter(this, void 0, void 0, function* () {
            const ext = nodepath.extname(relFile).toLowerCase();
            switch (ext) {
                case '.md': {
                    yield this.processMdFile(relFile);
                    break;
                }
                case '.json': {
                    yield this.processJsonFile(relFile);
                    break;
                }
                default: {
                    throw new Error(`Unsupported file type: ${ext}`);
                }
            }
        });
    }
    processMdFile(relFile) {
        return __awaiter(this, void 0, void 0, function* () {
            const relDir = this.pathManager.basePath(relFile);
            yield this.markdownManager.convertFileAsync(relFile);
            yield this.titleManager.updateFileTitleAsync(relFile);
            yield this.titleManager.updateDirTitleAsync(relDir, true);
            yield this.seoTitleManager.updateCalculatedTitle(relFile);
            yield this.pathBarManager.updatePathBar(relDir);
            yield this.fileListManager.updateFileList(relDir, true);
        });
    }
    processJsonFile(relFile) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.copyManager.copyFileAsync(relFile);
        });
    }
}
exports.Processor = Processor;
//# sourceMappingURL=core.js.map