"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const common_1 = require("./common");
const defs_1 = require("../../defs");
const mfs = require("m-fs");
class FileListManager {
    constructor(config, state, pathManager, titleManager, pathInfoManager, fsWalkManager, contentGenerator) {
        this.config = config;
        this.state = state;
        this.pathManager = pathManager;
        this.titleManager = titleManager;
        this.pathInfoManager = pathInfoManager;
        this.fsWalkManager = fsWalkManager;
        this.contentGenerator = contentGenerator;
    }
    updateFileList(relDir, recursive) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!relDir) {
                return new common_1.Result([], false);
            }
            const state = this.state;
            if (state.dirFileList[relDir]) {
                return new common_1.Result(state.dirFileList[relDir], true);
            }
            const isLeaf = yield this.fsWalkManager.isLeafDirAsync(relDir);
            let fileList;
            if (isLeaf) {
                const files = yield this.fsWalkManager.listSubFilesAsync(relDir);
                fileList = yield this.pathInfoManager.infoFromFilesAsync(files);
            }
            else {
                const dirs = yield this.fsWalkManager.listSubDirsAsync(relDir);
                fileList = yield this.pathInfoManager.infoFromDirsAsync(dirs);
            }
            state.dirFileList[relDir] = fileList;
            const contentHtml = this.contentGenerator.generateContentHtml(fileList);
            const destFile = this.pathManager.joinedDestPath(relDir, defs_1.default.dest.dirFileListFile);
            yield mfs.writeFileAsync(destFile, contentHtml);
            if (recursive) {
                const parentDir = this.pathManager.basePath(relDir);
                yield this.updateFileList(parentDir, true);
            }
            return new common_1.Result(fileList, false);
        });
    }
}
exports.default = FileListManager;
//# sourceMappingURL=fileListManager.js.map