"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const common_1 = require("./common");
const defs_1 = require("../../defs");
const mfs = require("m-fs");
class PathBarManager {
    constructor(config, state, pathManager, titleManager, pathInfoManager, contentGenerator) {
        this.config = config;
        this.state = state;
        this.pathManager = pathManager;
        this.titleManager = titleManager;
        this.pathInfoManager = pathInfoManager;
        this.contentGenerator = contentGenerator;
    }
    updatePathBar(relDir) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!relDir) {
                return new common_1.Result([], false);
            }
            const state = this.state;
            if (state.dirPathBar[relDir]) {
                return new common_1.Result(state.dirPathBar[relDir], true);
            }
            const parentDir = this.pathManager.basePath(relDir);
            const paths = (yield this.updatePathBar(parentDir)).result;
            paths.push((yield this.pathInfoManager.infoFromDirAsync(relDir)).result);
            state.dirPathBar[relDir] = paths;
            const contentHtml = this.contentGenerator.generatePathBarHtml(paths);
            const destFile = this.pathManager.joinedDestPath(relDir, defs_1.default.dest.dirPathBarFile);
            yield mfs.writeFileAsync(destFile, contentHtml);
            return new common_1.Result(paths, false);
        });
    }
}
exports.default = PathBarManager;
//# sourceMappingURL=pathBarManager.js.map