"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const pathInfo_1 = require("../../pathInfo");
const common_1 = require("./common");
class PathInfoManager {
    constructor(config, state, pathManager, titleManager) {
        this.config = config;
        this.state = state;
        this.pathManager = pathManager;
        this.titleManager = titleManager;
    }
    infoFromFileAsync(relFile) {
        return __awaiter(this, void 0, void 0, function* () {
            const state = this.state;
            if (state.filePathInfo[relFile]) {
                return new common_1.Result(state.filePathInfo[relFile], true);
            }
            const name = this.pathManager.nameWithoutExt(relFile);
            const title = (yield this.titleManager.updateFileTitleAsync(relFile)).result;
            const parentDir = this.pathManager.basePath(relFile);
            const parentInfo = (yield this.infoFromDirAsync(parentDir)).result;
            const component = pathInfo_1.default.newInfo(name, title, parentInfo);
            state.filePathInfo[relFile] = component;
            return new common_1.Result(component, false);
        });
    }
    infoFromDirAsync(relDir) {
        return __awaiter(this, void 0, void 0, function* () {
            const state = this.state;
            if (state.dirPathInfo[relDir]) {
                return new common_1.Result(state.dirPathInfo[relDir], true);
            }
            const name = this.pathManager.name(relDir);
            const title = (yield this.titleManager.updateDirTitleAsync(relDir, false)).result;
            const parentDir = this.pathManager.basePath(relDir);
            let parentInfo = null;
            if (parentDir) {
                parentInfo = (yield this.infoFromDirAsync(parentDir)).result;
            }
            else {
                parentInfo = pathInfo_1.default.newRootInfo(this.config.rootURL);
            }
            const component = pathInfo_1.default.newInfo(name, title, parentInfo);
            state.dirPathInfo[relDir] = component;
            return new common_1.Result(component, false);
        });
    }
    infoFromFilesAsync(relFiles) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield Promise.all(relFiles.map((d) => __awaiter(this, void 0, void 0, function* () {
                return (yield this.infoFromFileAsync(d)).result;
            })));
        });
    }
    infoFromDirsAsync(relDirs) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield Promise.all(relDirs.map((d) => __awaiter(this, void 0, void 0, function* () {
                return (yield this.infoFromDirAsync(d)).result;
            })));
        });
    }
}
exports.default = PathInfoManager;
//# sourceMappingURL=pathInfoManager.js.map