"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const state_1 = require("../state");
const common_1 = require("./common");
const defs_1 = require("../../defs");
const mfs = require("m-fs");
const node_rename_path_1 = require("node-rename-path");
const trimEnd = require('lodash.trimend');
const escapeHTML = require('escape-html');
class SeoTitleManager {
    constructor(config, state, titleManager, pathManager) {
        this.config = config;
        this.state = state;
        this.titleManager = titleManager;
        this.pathManager = pathManager;
    }
    updateCalculatedTitle(relFile) {
        return __awaiter(this, void 0, void 0, function* () {
            const state = this.state;
            if (state.fileSeoTitle[relFile]) {
                return new common_1.Result(state.fileSeoTitle[relFile], true);
            }
            const baseDir = this.pathManager.basePath(relFile);
            const inheritedSeoTitle = (yield this.updateSeoTitleForDir(baseDir)).result.inheritedTitle;
            const title = (yield this.titleManager.updateFileTitleAsync(relFile)).result;
            const calcTitle = this.getCalculatedTitle(title, inheritedSeoTitle);
            const seoTitleData = new state_1.SeoTitleData(calcTitle, inheritedSeoTitle);
            state.fileSeoTitle[relFile] = seoTitleData;
            yield this.writeFileTitleFile(relFile, calcTitle);
            return new common_1.Result(seoTitleData, false);
        });
    }
    updateSeoTitleForDir(relDir) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!relDir) {
                return new common_1.Result(new state_1.SeoTitleData('', ''), false);
            }
            const state = this.state;
            const dicValue = state.dirSeoTitle[relDir];
            if (dicValue) {
                return new common_1.Result(dicValue, true);
            }
            const parentDir = this.pathManager.basePath(relDir);
            if (!parentDir) {
                return new common_1.Result(new state_1.SeoTitleData('', ''), false);
            }
            const srcSeoTitleFile = this.pathManager.joinedSrcPath(parentDir, defs_1.default.src.seoTitleFile);
            let inheritedSeoTitle = '';
            if (yield mfs.fileExists(srcSeoTitleFile)) {
                inheritedSeoTitle = trimEnd(yield mfs.readTextFileAsync(srcSeoTitleFile));
            }
            else {
                inheritedSeoTitle = (yield this.updateSeoTitleForDir(parentDir)).result.inheritedTitle;
            }
            const title = (yield this.titleManager.updateDirTitleAsync(relDir, false)).result;
            const calcTitle = this.getCalculatedTitle(title, inheritedSeoTitle);
            const setTitleData = new state_1.SeoTitleData(calcTitle, inheritedSeoTitle);
            state.dirSeoTitle[relDir] = setTitleData;
            yield this.writeDirTitleFile(relDir, calcTitle);
            return new common_1.Result(setTitleData, false);
        });
    }
    writeFileTitleFile(relFile, title) {
        return __awaiter(this, void 0, void 0, function* () {
            const unescapedFile = node_rename_path_1.default(this.pathManager.destPath(relFile), (_) => {
                return { ext: defs_1.default.dest.seoTitleExt };
            });
            yield mfs.writeFileAsync(unescapedFile, title);
            const escapedFile = node_rename_path_1.default(this.pathManager.destPath(relFile), (_) => {
                return { ext: defs_1.default.dest.seoTitleHtmlExt };
            });
            yield mfs.writeFileAsync(escapedFile, escapeHTML(title));
        });
    }
    writeDirTitleFile(relDir, title) {
        return __awaiter(this, void 0, void 0, function* () {
            const unescapedFile = this.pathManager.joinedDestPath(relDir, defs_1.default.dest.dirSeoTitleFile);
            yield mfs.writeFileAsync(unescapedFile, title);
            const escapedFile = this.pathManager.joinedDestPath(relDir, defs_1.default.dest.dirSeoTitleHtmlFile);
            yield mfs.writeFileAsync(escapedFile, escapeHTML(title));
        });
    }
    getCalculatedTitle(title, seoTitle) {
        return (title || '') + (seoTitle || '');
    }
}
exports.default = SeoTitleManager;
//# sourceMappingURL=seoTitleManager.js.map